魂断蓝桥 (豆瓣)
Description: 魂断蓝桥电影简介和剧情介绍,魂断蓝桥影评、图片、预告片、影讯、论坛、在线购票
Keywords: 魂断蓝桥,Waterloo Bridge,魂断蓝桥影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.230豆瓣电影Top250

# 魂断蓝桥 Waterloo Bridge (1940)

导演: 茂文·勒鲁瓦
编剧: 塞缪尔·N·贝尔曼 / 汉斯·拉莫 / 乔治·弗罗斯切尔 / 罗伯特·E·舍伍德
主演: 费雯·丽 / 罗伯特·泰勒 / 露塞尔·沃特森 / 弗吉尼亚·菲尔德 / 玛丽亚·彭斯卡娅 / C.奥布雷·史密斯 / Janet Shaw / Janet Waldo / Steffi Duna / Virginia Carroll / Eleanor Stewart / Lowden Adams / Harry Allen / Jimmy Aubrey / Phyllis Barry / Colin Campbell / 丽塔·卡莱尔 / 里奥.G.卡罗尔 / 戴维·卡文迪什 / 大卫·克莱德 / 汤姆·康威 / Frank Dawson / Connie Emerald / Gilbert Emery / 赫伯特·埃文斯 / 迪克·戈登 / Denis Green / 艾塞尔·格里菲斯 / Bobby Hale / Winifred Harris / 哈利韦尔·霍布斯 / Harold Howard / Charles Irwin / George Kirby / Walter Lawrence / 威尔弗雷德·卢卡斯 / Dan Maxwell / James May / Florine McKinney / Charles McNaughton / Frank Mitchell / 埃德蒙·莫蒂默 / 伦纳德米迪 / 坦普·皮戈特 / John Power / Clara Reid / Paul Scardon / 约翰·格雷厄姆·斯佩西 / Wyndham Standing / 哈里·斯塔布斯 / Cyril Thornton / 戴维·瑟斯比 / 诺玛·威登 / 帕特·威尔士 / 玛莎·温特沃思 / Frank Whitbeck / Eric Wilton / 罗伯特·温克勒 / 道格拉斯·伍德
类型: 剧情 / 爱情 / 战争
制片国家/地区: 美国
语言: 英语 / 法语
上映日期: 1940-05-17(美国)
片长: 108分钟
又名: 滑铁卢桥 / 断桥残梦
IMDb: tt0033238
豆瓣评分
引用
8.8
263836人评价
5星
50.9%
4星
39.8%
3星
8.6%
2星
0.5%
1星
0.1%
好于 98% 爱情片
好于 97% 战争片
想看 看过
评价:
推荐

## 魂断蓝桥的剧情简介 · · · · · ·

第一次世界大战期间，回国度假的陆军中尉罗伊（罗伯特·泰勒）在滑铁卢桥上邂逅了舞蹈演员玛拉（费雯·丽），两人彼此倾心，爱情迅速升温。就在两人决定结婚之时，罗伊应招回营地，两人被迫分离。由于错过剧团演出，玛拉被开除，只能和好友相依为命。
不久玛拉得知罗伊阵亡的消息，几欲崩溃，备受打击。失去爱情的玛拉感到一切都失去了意义，为了生存，她和好友不得不沦为妓女。然而命运弄人，就在此时玛拉竟然再次遇到了罗伊。虽然为罗伊的生还兴奋不已，玛拉却因自己的失身陷入痛苦之中。
感到一切难以挽回的玛拉潸然离开，独自来到两人最初相遇的地点——滑铁卢桥上… ©豆瓣

## 魂断蓝桥的演职员 · · · · · · ( 全部 68 )

- 茂文·勒鲁瓦 导演
- 伍经纬 译制导演
- 费雯·丽 饰 Myra
- 罗伯特·泰勒 饰 Roy Cronin
- 露塞尔·沃特森 饰 Lady Margaret Cronin
- 弗吉尼亚·菲尔德 饰 Kitty

## 魂断蓝桥的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片478 · 添加 )

## 魂断蓝桥的获奖情况 · · · · · · ( 全部 )

- 第13届奥斯卡金像奖
- 黑白片最佳摄影(提名)
- 约瑟夫·拉滕伯格

- 第13届奥斯卡金像奖
- 最佳原创配乐(提名)
- 赫伯特·斯托萨特

## 喜欢这部电影的人也喜欢 · · · · · ·

  罗马假日

  卡萨布兰卡

  乱世佳人

  人鬼情未了

  爱在日落黄昏时

  甜蜜蜜

  恋恋笔记本

  蒂凡尼的早餐

  廊桥遗梦

  花样年华

我要写短评

## 魂断蓝桥的短评 · · · · · · ( 全部 54064 条 )

热门 / 最新 / 好友

### 2748 有用 铎奇 看过 2012-12-20 04:30:48

真爱不是订婚之后隔天就跑去打仗再无音信，真爱是一起去车站揽活儿。Kitty才是真爱Myra。

### 1496 有用 果酱☮ 看过 2009-02-19 05:45:50

真正的经典电影绝非是口口相传，继而跟风装B，而是即便过了那么多个时代，如今看来依旧让人发自内心由衷地喜爱它称赞它。此片真的是经典，费雯丽的表演震慑人心令人难以忘怀。尤其是从她极为迷人的大眼睛流露出的眼神里包含着的各种情绪（而不是像如今很多女星那般眼大却无神），羞涩甜蜜幸福绝望绝决

### 573 有用 冰红深蓝 看过 2015-03-21 14:29:35

片子本身中规中矩，费雯·丽演技要加分！全片明确回避了“prostitute/whore”词汇，爱情戏也拍得比较克制，滑铁卢桥自杀场景的剪辑很棒，主题曲《Auld Lang Syne》闻名遐迩，让人百听不厌~ 但个人极度不赞成电影宣扬的这种保守甚至扭曲的价值观，更喜欢女二号的性格和思想。（8.0/10）

### 943 有用 朝暮雪 看过 2017-04-19 10:23:49

身体是你自己的，你不需要为自己失身而感到抱歉。

### 932 有用 囍夭夭 看过 2009-11-19 23:03:49

中国式内在的美国电影。。。

> 更多短评 54064条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 魂断蓝桥的影评 · · · · · · ( 全部 735 条 )

热门 / 最新 / 好友
W小姐（吴桐） 2010-08-21 00:59:45

## 命运悲剧与性格悲剧

以前表演课的时候老师讲过悲剧分为两种，一种是性格悲剧，一种是命运悲剧。 命运悲剧有俄狄浦斯王弑父娶母，性格悲剧有哈姆雷特永恒的疑问：“生存还是毁灭, 这是个问题， 是否应默默的忍受坎坷命运之无情打击，还是应与深如大海之无涯苦难奋然为敌，并将其克服。此二抉择，究... (展开)
2024 175 353回应 收起
R 2011-11-18 16:23:07

## 如果女主角是基蒂

这篇影评可能有剧透

我一直在想，如果电影中的女主角是基蒂，那么将会是完全不同的结局。 电影中玛拉和好朋友基蒂，可以说两个女孩子同样令人喜爱和心疼，但两个人的性格却是鲜明的对比，形成了强烈的反差。 玛拉在爱情面前自尊、忠厚、纯洁、脆弱，令人心疼。然而这些性格特质也导... (展开)
714 28 72回应 收起
陶陶四 2008-01-25 20:53:59

## 对谁都好

终于想要写一点东西了。不管是狭隘或者偏执，在看了钢琴别恋看了超市夜未眠看了许许多多的爱情片后终于想要写点东西了。 本来就是老电影，rmvb格式拷下来，很多镜头都带着一种残破的灰色。密密麻麻的夹杂着那个时代的味道。 好久以来，第一个想要是喜剧结尾的电影。看文艺电影... (展开)
245 24 28回应 收起
你踩着我肥皂了 2018-05-23 10:40:02

## 纯爱电影

空袭的阴影下相遇，三幕戏便盛开了情花。归途的车站上重逢，欲说还休的是沦落风尘的阴霾。那夜她回到初见的桥，只留下一道朦胧身影，诉说着不舍爱恋。纵使情深如海，也抵不过心的愧疚。所有宁为玉碎，只为爱的无瑕。此后她如一个传奇梦，永存他追忆叹息中。 费雯丽的表演又美又... (展开)
84 1 0回应 收起
清暉 2012-02-26 20:03:40

## 老欧洲人恋爱的表情

其实应该理解成好莱坞电影对老欧洲温情脉脉的回忆，何况还是在二战这个节骨眼儿上。反正写影评不是我专长，我是被这个故事整体的叙述语调迷住了，有点儿伤感。 费雯丽的面孔混合着清纯和一点点肉欲，但总体看来非常天真，散发着一种出于本性的善良以及敏感脆弱的气质... (展开)
90 3 5回应 收起
橘猫爱吃鱼 2018-01-30 10:45:52

## 战争是残酷的

若说罗伊和玛拉的爱情全拜战争所赐亦不为过，如果没有战争，也就不一定会有桥上的邂逅，即便相识之后也不会因时间的紧迫而那么快地订下婚约。也正是因为战争，令他们的感情受尽了艰辛与挫折，以致最终的天人永隔。因为战争原因而堕入红尘的玛拉经过了费雯丽的演绎，其善良、美... (展开)
36 2回应 收起
傻不傻666 2017-05-15 22:39:01

## 一个美丽的邂逅，一份痴情的等待

这是一个美的让人忍不住落泪的爱情故事，那么在看完这部影片之前忍住你的眼泪，否则你感觉不到战争留下的残酷。。。。 在天鹅湖凄美的音乐声中开场，似乎你已经预示到了那个悲惨的结局，但是当那一刻真的到来时，你还是承受不起那份巨大落差所带来的失落。。。 在战争年代的背... (展开)
37 3 3回应 收起
Maverick 2017-02-12 17:22:38

## 《魂断蓝桥》电影剧本

《魂断蓝桥》电影剧本 （根据罗勃肖伍特同名舞台剧改编） 编剧：S·N·白门、汉斯·雷缪，乔治·弗罗薛尔 夜晚的伦敦街头。 黑暗的马路，居民们在专心听广播。马路两旁堆集着沙袋，战争已经开始。 （画外广播）：“全世界都知道了。一九三九年九月三日，星期天，它将永远被... (展开)
35 5回应 收起

> 更多影评 735篇

添加新讨论

## 讨论区 · · · · · ·

译名 | 来自在拐弯处停车 |  | 2022-11-13 13:16:21
这部电影讲的就是一个洗头房妹子的前传吧... | 来自lloydbanks | 4 回应 | 2022-11-11 20:06:27
实在觉得剧情很狗血 | 来自逆飞的鱼 | 90 回应 | 2022-11-11 20:04:52
费雯·丽和上尉的上司跳舞 看到他的臂章 费雯丽的... | 来自豆友205786977 | 1 回应 | 2022-11-10 10:07:37
战争带给女性什么 | 来自娜 | 2 回应 | 2022-11-02 10:14:16

> 去这部影片的讨论区（全部118条）

## 关于《魂断蓝桥》的问题 · · · · · · ( 全部5个 )

- 女主真的要沦落到做那种事吗？ 4人回答
- 很奇怪 魂断蓝桥作为豆瓣top250的196名，影评观看数最高的只有800多，提问也只有2个问题？ 2人回答

> 全部5个问题

## 在哪儿看这部电影 · · · · · ·

- 腾讯视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 1905电影网 VIP免费观看
- 哔哩哔哩 免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 深情即是一桩悲剧，必得以死来句读。 (眠去)
- 【内牛满面】 (影志)
- 那些牛叉闪闪的片子 (家庭种菜笔记)
- 入选《第十放映室》影片之国外篇Ⅱ (心之旋影)

## 谁在看这部电影 · · · · · ·

- YING
  刚刚 想看
- 杨坚强
  4分钟前 看过
- momo
  12分钟前 想看

451685人看过 / 224862人想看

订阅魂断蓝桥的评论:
feed: rss 2.0